pub struct StorageVariable {
pub name: String,
pub ty: StorageType,
}Expand description
A storage variable declaration.
Lowering
Storage variables are lowered to mappings in Aleo bytecode:
storage x: Tbecomesmapping x__: bool => T(value stored at keyfalse)
Fields
name: Stringty: StorageTypeTrait Implementations
Sourceimpl Clone for StorageVariable
impl Clone for StorageVariable
Sourcefn clone(&self) -> StorageVariable
fn clone(&self) -> StorageVariable
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StorageVariable
impl Debug for StorageVariable
Sourceimpl<'de> Deserialize<'de> for StorageVariable
impl<'de> Deserialize<'de> for StorageVariable
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for StorageVariable
impl PartialEq for StorageVariable
Sourcefn eq(&self, other: &StorageVariable) -> bool
fn eq(&self, other: &StorageVariable) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for StorageVariable
impl Serialize for StorageVariable
impl Eq for StorageVariable
impl StructuralPartialEq for StorageVariable